"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.retrieveWebidTrustedOidcIssuers = void 0;
const n3_1 = require("n3");
const rdf_dereference_1 = __importDefault(require("rdf-dereference"));
const error_1 = require("../error");
const defaultGraph = n3_1.DataFactory.defaultGraph();
const oidcIssuer = n3_1.DataFactory.namedNode("http://www.w3.org/ns/solid/terms#oidcIssuer");
async function dereferenceWebid(webid) {
    try {
        return (await rdf_dereference_1.default.dereference(webid)).quads;
    }
    catch (e) {
        throw new error_1.WebidDereferencingError(webid);
    }
}
async function retrieveWebidTrustedOidcIssuers(webid, getIssuers) {
    if (typeof getIssuers !== "undefined" && getIssuers !== null) {
        return getIssuers(webid);
    }
    const issuers = [];
    const webidNode = n3_1.DataFactory.namedNode(webid);
    const quadStream = await dereferenceWebid(webid);
    return new Promise((resolve, reject) => {
        quadStream
            .on("data", ({ subject, predicate, object, graph }) => {
            if (defaultGraph.equals(graph) &&
                object.termType === "NamedNode" &&
                oidcIssuer.equals(predicate) &&
                webidNode.equals(subject)) {
                issuers.push(object.value);
            }
        })
            .on("end", () => resolve(issuers))
            .on("error", reject);
    });
}
exports.retrieveWebidTrustedOidcIssuers = retrieveWebidTrustedOidcIssuers;
//# sourceMappingURL=retrieveWebidTrustedOidcIssuers.js.map